/**
 * This file is part of Advanced Custom Fields: Grid.
 *
 * Advanced Custom Fields: Grid is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation, either version 2 of the License, or any later version.
 *
 * Advanced Custom Fields: Grid is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * Advanced Custom Fields: Grid.  If not, see <https://www.gnu.org/licenses/>.
 */
import { __ } from '@wordpress/i18n';
import {
	__experimentalNumberControl as NumberControl,
	PanelBody,
	Placeholder,
	TextControl,
	ToggleControl,
} from '@wordpress/components';
import { InspectorControls, useBlockProps, } from '@wordpress/block-editor';
import icon from './icon';


export default function edit( { attributes, setAttributes } ) {
	const {
		fieldName,
		useLightbox,
		lightboxGallery,
		desktopColumns,
		tabletColumns,
		mobileColumns,
		gutter,
	} = attributes;
	const isStyle = RegExp( /is-style-/ )
	const styleName = isStyle.test( attributes.className )
		? attributes.className.replace( isStyle, '' )
		: null
	console.log( styleName );
	const templateSelect = <TextControl
		label={ __( 'Gallery Field Name', 'acf-grid' ) }
		value={ fieldName }
		onChange={ ( value ) => {
			setAttributes( {
				fieldName: value,
			} )
		} }
	/>;
	return (
		<div  { ...useBlockProps() } >
			<InspectorControls>
				<PanelBody
					title={ __( 'ACF Grid settings', 'acf-grid' ) }>
					{ templateSelect }
					<ToggleControl
						label={ __( 'Show images in a lightbox', 'acf-grid' ) }
						checked={ useLightbox }
						onChange={ ( useLightbox ) => setAttributes( { useLightbox } ) }
					/>
					{ useLightbox &&
						<ToggleControl
							label={ __( 'Show lightbox images as a gallery', 'acf-grid' ) }
							checked={ lightboxGallery }
							onChange={ ( lightboxGallery ) => setAttributes( { lightboxGallery } ) }
						/>
					}
				</PanelBody>
				<PanelBody
					title={ __( 'Columns', 'acf-grid' ) }
				>
					<NumberControl
						label={ __( 'Desktop', 'acf-grid' ) }
						min="1"
						max="4"
						value={ desktopColumns }
						onChange={ ( value ) => setAttributes( {
							desktopColumns: parseInt( value, 10 ),
						} ) }
					/>
					<NumberControl
						label={ __( 'Tablet', 'acf-grid' ) }
						min="1"
						max="4"
						value={ tabletColumns }
						onChange={ ( value ) => setAttributes( {
							tabletColumns: parseInt( value, 10 ),
						} ) }
					/>
					<NumberControl
						label={ __( 'Mobile', 'acf-grid' ) }
						min="1"
						max="4"
						value={ mobileColumns }
						onChange={ ( value ) => setAttributes( {
							mobileColumns: parseInt( value, 10 ),
						} ) }
					/>
				</PanelBody>
				{ styleName === 'masonry' && <PanelBody title={ __( 'Masonry', 'acf-grid' ) }>
					<NumberControl
						label={ __( 'Gutter', 'acf-grid' ) }
						min="0"
						value={ gutter }
						onChange={ ( value ) => setAttributes( {
							gutter: parseInt( value, 10 ),
						} ) }
					/>
				</PanelBody> }
			</InspectorControls>
			<Placeholder icon={ icon } label={ __( 'ACF Grid', 'acf-grid' ) }>
				{ templateSelect }
			</Placeholder>
		</div>
	);
}
